import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class DropDownView<T> extends StatefulWidget {
  final T? initialValue;
  final List<T> values;
  final Function onSelected;
  final String? label;

  DropDownView({
    this.initialValue,
    required this.values,
    required this.onSelected,
    this.label,
  });

  @override
  _DropDownViewState createState() => _DropDownViewState<T>();
}

class _DropDownViewState<T> extends State<DropDownView> {
  @override
  Widget build(BuildContext context) {
    final List<DropdownMenuItem<T>> items = [for (final value in widget.values) DropdownMenuItem<T>(
      value: value,
      child: Text(value.toString()),
    )];

    return SizedBox(
      height: kIsWeb ? 50 : 60,
      child: DropdownButtonFormField<T>(
          decoration: InputDecoration(
              labelText: widget.label,
              border: OutlineInputBorder()
          ),
          validator: (value) {
            return null;
          },
          isExpanded: true,
          value: widget.values.contains(widget.initialValue) ? widget.initialValue : widget.values.first,
          iconEnabledColor: Colors.grey,
          icon: Icon(Icons.keyboard_arrow_down),
          iconSize: 24,
          elevation: 16,
          onChanged: (T? value) {
            widget.onSelected(value);
          },
          items: items
      ),
    );
  }
}
